summaryrefslogtreecommitdiffstats
path: root/Lib/runpy.py
diff options
context:
space:
mode:
authorHumbled Drugman <humbled.drugman@gmail.com>2022-04-29 18:22:46 (GMT)
committerGitHub <noreply@github.com>2022-04-29 18:22:46 (GMT)
commit117836f123a1c65d9ba50401822b883f11f0a347 (patch)
tree4154f3b5d723753a0a9bfe9d308b81a0dc4e2ba8 /Lib/runpy.py
parent83bce8ef14ee5546cb3d60f398f0cbb04bd3d9df (diff)
downloadcpython-117836f123a1c65d9ba50401822b883f11f0a347.zip
cpython-117836f123a1c65d9ba50401822b883f11f0a347.tar.gz
cpython-117836f123a1c65d9ba50401822b883f11f0a347.tar.bz2
bpo-26792: Improve docstrings of runpy module run_functions (#30729)
Co-authored-by: Jelle Zijlstra <jelle.zijlstra@gmail.com> Co-authored-by: Kumar Aditya <59607654+kumaraditya303@users.noreply.github.com>
Diffstat (limited to 'Lib/runpy.py')
-rw-r--r--Lib/runpy.py36
1 files changed, 28 insertions, 8 deletions
diff --git a/Lib/runpy.py b/Lib/runpy.py
index 949fd59..54fc136 100644
--- a/Lib/runpy.py
+++ b/Lib/runpy.py
@@ -200,9 +200,24 @@ def _run_module_as_main(mod_name, alter_argv=True):
def run_module(mod_name, init_globals=None,
run_name=None, alter_sys=False):
- """Execute a module's code without importing it
+ """Execute a module's code without importing it.
- Returns the resulting top level namespace dictionary
+ mod_name -- an absolute module name or package name.
+
+ Optional arguments:
+ init_globals -- dictionary used to pre-populate the module’s
+ globals dictionary before the code is executed.
+
+ run_name -- if not None, this will be used for setting __name__;
+ otherwise, __name__ will be set to mod_name + '__main__' if the
+ named module is a package and to just mod_name otherwise.
+
+ alter_sys -- if True, sys.argv[0] is updated with the value of
+ __file__ and sys.modules[__name__] is updated with a temporary
+ module object for the module being executed. Both are
+ restored to their original values before the function returns.
+
+ Returns the resulting module globals dictionary.
"""
mod_name, mod_spec, code = _get_module_details(mod_name)
if run_name is None:
@@ -245,14 +260,19 @@ def _get_code_from_file(run_name, fname):
return code, fname
def run_path(path_name, init_globals=None, run_name=None):
- """Execute code located at the specified filesystem location
+ """Execute code located at the specified filesystem location.
+
+ path_name -- filesystem location of a Python script, zipfile,
+ or directory containing a top level __main__.py script.
+
+ Optional arguments:
+ init_globals -- dictionary used to pre-populate the module’s
+ globals dictionary before the code is executed.
- Returns the resulting top level namespace dictionary
+ run_name -- if not None, this will be used to set __name__;
+ otherwise, '<run_path>' will be used for __name__.
- The file path may refer directly to a Python script (i.e.
- one that could be directly executed with execfile) or else
- it may refer to a zipfile or directory containing a top
- level __main__.py script.
+ Returns the resulting module globals dictionary.
"""
if run_name is None:
run_name = "<run_path>"